package org.codehaus.plexus.components.io.resources;

/*
 * Copyright 2007 The Codehaus Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.File;

/**
 * Extension of {@link PlexusIoResourceCollection} for archive
 * files: Zip, tar, gzip, bzip2, etc. files.
 */
public interface PlexusIoArchivedResourceCollection
    extends PlexusIoResourceCollection
{
    /**
     * Sets the arcihve file
     */
    void setFile( File file );

    /**
     * Returns the archive file
     */
    File getFile();
}